Targets
=======

.. toctree::
  :maxdepth: 2
  :hidden:

  target_fields
  ../api/tom_targets/models
  ../api/tom_targets/views


The ``Target``, along with the associated ``TargetList``, ``TargetExtra``, and ``TargetName``, are the core models of the 
TOM Toolkit. The ``Target`` defines the concept of an astronomical target.

:doc:`Adding Custom Target Fields <target_fields>` - Learn how to add custom fields to your TOM Targets if the
defaults do not suffice.

:doc:`Target API <../api/tom_targets/models>` - Take a look at the available properties for a ``Target`` and its associated models.

:doc:`Target Views <../api/tom_targets/views>` - Familiarize yourself with the available Target Views.

:doc:`Target Groups <../api/tom_targets/groups>` - Check out the functions for operating on Target Groups.
